# -*- coding:utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - test/latua/core/test_files.py

latua test class for files

"""

__version__ = "$Revision: 199 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/test/latua/_system/test_files.py $

## standard modules
import os
import tempfile
import unittest

## latua modules
import latua

class FilesTestCase(unittest.TestCase):
    """Test cases for latua files class."""
    def setUp(self):
        """Test set up."""
        self.__system = latua.System()
        self.__test_directory = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, os.pardir))
        self.__test_file_handle, self.__test_file_name = tempfile.mkstemp(prefix="latua_test_temp_", dir=self.__test_directory)

    def test_integrity(self):
        """Test files integrity."""
        result = self.__system.files.integrity(os.path.dirname(self.__test_file_name), [os.path.basename(self.__test_file_name)])
        self.assertEqual(len(result), 0,
                         "failed to check integrity for existing file %s" % (self.__test_file_name))
        handle, name = tempfile.mkstemp(prefix="latua_test_temp_", dir=self.__test_directory)
        os.close(handle)
        os.remove(name)
        result = self.__system.files.integrity(os.path.dirname(name), [os.path.basename(name)])
        self.assertEqual(result, [os.path.basename(name)],
                         "failed to check integrity for non-existent file %s" % (name))

    def test_permission(self):
        """Test files permission."""
        os.chmod(self.__test_file_name, 0000)
        result = self.__system.files.permission(self.__test_file_name)
        self.assertEqual(result, ("---", "---", "---"),
                         "permission do not match expected 0000")
        os.chmod(self.__test_file_name, 0444)
        result = self.__system.files.permission(self.__test_file_name)
        self.assertEqual(result, ("r--", "r--", "r--"),
                         "permission do not match expected 0444")
        os.chmod(self.__test_file_name, 0555)
        result = self.__system.files.permission(self.__test_file_name)
        self.assertEqual(result, ("r-x", "r-x", "r-x"),
                         "permission do not match expected 0555")
        os.chmod(self.__test_file_name, 0666)
        result = self.__system.files.permission(self.__test_file_name)
        self.assertEqual(result, ("rw-", "rw-", "rw-"),
                         "permission do not match expected 0666")
        os.chmod(self.__test_file_name, 0777)
        result = self.__system.files.permission(self.__test_file_name)
        self.assertEqual(result, ("rwx", "rwx", "rwx"),
                         "permission do not match expected 0777")

    def test_search(self):
        """Test files search."""
        result = self.__system.files.search(self.__test_directory, "file", ".py", absolute=False)
        self.assert_(len(result) > 0, "search found no files")
        ## search result contains at least one init file
        self.assertEqual(os.path.join(self.__test_directory, "__init__.py") in result, True,
                         "no init file found in search result")
        result = self.__system.files.search(self.__test_directory, "directory", absolute=False)
        self.assert_(len(result) > 0, "search found no files")
        ## search result contains at least the latua directory
        self.assertEqual(os.path.join(self.__test_directory, "latua") in result, True,
                         "latua directiory not found in search result")

    def tearDown(self):
        """Clean up after tests."""
        os.close(self.__test_file_handle)
        os.remove(self.__test_file_name)
        self.__test_file_handle = None
        self.__test_file_name = None
        self.__test_directory = None
        self.__system = None

if __name__ == "__main__":
    print """
do not run this file directly, use latua test script

    """



# -*- coding:utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - test/latua/core/test_modules.py

latua test class for modules

"""

__version__ = "$Revision: 190 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/test/latua/_system/test_modules.py $

## standard modules
import os
import imp
import unittest

## latua modules
import latua
import latua.error

class ModulesTestCase(unittest.TestCase):
    """Test cases for latuas modules class."""
    def setUp(self):
        """Test set up."""
        self.__system = latua.System()
        self.__test_module = imp.new_module("test_module")

    def test_append(self):
        """Test modules modules append."""
        self.__system.modules.append(latua, "test_sub.test_module", self.__test_module)
        self.assertEqual(latua.test_sub.test_module, self.__test_module)

    def test_empty(self):
        """Test modules exception."""
        self.assertRaises(latua.error.ModulesError, self.__system.modules.append, latua, "")

    def test_filename(self):
        """Test system filename conversion."""
        result = self.__system.modules.filename_modulename(os.path.join("latua", "test.py"))
        self.assertEqual(result, "latua.test",
                         "conversion of filename to modulename failed")

    def test_import(self):
        """Test modules import."""
        result = self.__system.modules._import("latua._version", "_Version")
        self.assertEqual(result.license, "BSD")

    def test_modulename(self):
        """Test system modulename conversion."""
        result = self.__system.modules.modulename_filename("latua.test")
        self.assertEqual(result, os.path.join("latua", "test%spy" % (os.path.extsep)),
                         "conversion of modulename to filename failed")

    def tearDown(self):
        """Clean up after tests."""
        self.__test_module = None
        self.__system = None

if __name__ == "__main__":
    print """
do not run this file directly, use latua test script

    """



# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - latua/_base/_platform.py

platform specific variables

the platform class sets all platform specific variables
for the actual correct platform

no need to check the platform again and again in other classes

"""

__version__ = "$Revision: 204 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/latua/_base/_platform.py $

## standard modules
import os
import sys
import stat
import locale
import logging
import logging.handlers

## unix specific modules
if os.name == "posix":
    ## a posix systems have a passwd
    import pwd

## windows specific modules
if sys.platform == "win32":
    ## these modules are usually
    ## installed by windows users
    try:
        import win32file
        import win32com
        import win32api
    except ImportError, error:
        raise latua.error.PlatformError("windows",
                                        "unable to import windows extensions",
                                        error)

## latua modules
import latua._context
import latua.error

class _Platform(object):
    """Get operating system and associating variables."""
    def __init__(self):
        ## set platform dictionary to context
        self.__platform = latua._context._platform
        if len(self.__platform) == 0:
            ## initialize platform dictionary
            self.__default()
            if sys.platform == "win32":
                ## windows
                self.__windows()
            if sys.platform == "darwin":
                ## mac os x
                self.__darwin()
        ## restore all already initialized variables from
        ## platform dictionary which points to the actual context
        ## the update of the class dictionary appends
        ## all variables as attributes to the object
        self.__dict__.update(self.__platform)

    def __default(self):
        """Initialize default platform settings."""
        ## assume application is started via script
        ## and get path of the script from arguments
        path = os.path.abspath(sys.argv[0])
        ## username
        self.__platform["user"] = os.getenv("USER")
        ## after su the user in environment is
        ## set to username instead of root
        ## check against uid
        if os.getuid() == 0:
            self.__platform["user"] = "root"
        ## application name
        self.__platform["application_name"] = os.path.basename(path)
        ## application directory
        self.__platform["application_directory"] = os.path.dirname(path)
        ## modules directory
        ## assume this platform module __file__
        ## is installed into the same modules path
        self.__platform["modules_directory"] = os.path.join(os.path.dirname(__file__), os.path.pardir)
        ## use modules directory as fallback
        home = self.__platform["modules_directory"]
        if os.name == "posix":
            ## get home directory from passwd on posix systems
            home = pwd.getpwuid(os.getuid())[5]
        ## users home directory
        self.__platform["home_directory"] = os.getenv("HOME", os.getenv("USERPROFILE", home))
        ## where to install configuration files
        self.__platform["configuration_directory"] = os.path.join(self.__platform["home_directory"], ".%s" % (self.__platform["application_name"]))
        if self.__platform["user"] == "root":
            ## use systems configuration directory
            self.__platform["configuration_directory"] = os.path.expanduser(os.path.join(os.path.sep, "etc", self.__platform["application_name"]))
        ## directory for data files
        self.__platform["data_directory"] = os.path.join(sys.prefix, "share", self.__platform["application_name"])
        ## all languages
        self.__platform["languages"] = locale.locale_alias.keys()
        ## locales directory
        self.__platform["locales_directory"] = os.path.join(sys.prefix, "share", "locale")
        if os.path.isdir(os.path.join(self.__platform["application_directory"], "locale")):
            ## application was started from local directory without installation
            self.__platform["locales_directory"] = os.path.join(self.application_directory, "locale")
            self.__platform["data_directory"] = self.application_directory
        ## logging handler
        socket = os.path.join(os.path.sep, "dev", "log")
        ## path to socket should exist (not a file)
        if os.path.exists(socket) and stat.S_ISSOCK(os.stat(socket)[stat.ST_MODE]):
            ## unix domain socket
            self.__platform["logging_handler"] = logging.handlers.SysLogHandler(socket)
        else:
            ## try to use default localhost port 514
            self.__platform["logging_handler"] = logging.handlers.SysLogHandler()
        ## logging directory
        self.__platform["logging_directory"] = self.__platform["configuration_directory"]
        if self.__platform["user"] == "root":
            self.__platform["logging_directory"] = os.path.join(os.path.sep, "var", "log")
        ## default logging level
        self.__platform["logging_level"] = logging.INFO
        ## how to start commands with files
        self.__platform["command_file"] = "%s %s"
        ## hidden files
        self.__platform["hidden"] = self.__default_hidden

    def __default_hidden(self, path):
        """Check path for hidden files or directories."""
        path = os.path.abspath(path)
        if os.path.exists(path):
            result = False
            for item in path.split(os.path.sep):
                if len(item) > 0 and item[0] == ".":
                    ## at least one component of path is hidden
                    result = True
            return result
        else:
            raise latua.error.PlatformError("hidden",
                                            "%s does not exist" % (path))

    def __darwin(self):
        """Initialize darwin platform specific settings."""
        ## syslog handler
        self.__platform["logging_handler"] = logging.handlers.SysLogHandler(os.path.join(os.path.sep, "var", "run","syslog"))
        ## mac os x tiger need at least log level warning by default
        self.__platform["logging_level"] = logging.WARNING

    def __windows(self):
        """Initialize windows platform specific settings."""
        id = win32com.shell.shell.SHGetSpecialFolderLocation(0, win32com.shell.shellcon.CSIDL_APPDATA)
        appdata = win32com.shell.shell.SHGetPathFromIDList(id)
        ## get application data folder on windows
        ## environ appdata is not available on unix
        path = os.getenv("APPDATA", appdata)
        ## username
        self.__platform["user"] = os.environ["USERNAME"]
        ## application directory
        self.__platform["application_directory"] = path
        ## where to install configuration files
        self.__platform["configuration_directory"] = os.path.join(self.__platform["self.application_directory"], self.__platform["application_name"])
        ## directory for data files
        self.__platform["data_directory"] = self.__platform["configuration_directory"]
        ## all languages
        self.__platform["languages"] = locale.windows_locale.values()
        ## locales directory
        self.__platform["locales_directory"] = os.path.join(self.__platform["self.data_directory"], "locale")
        ## syslog handler
        ## depends on win32 extensions too
        self.__platform["logging_handler"] = logging.handlers.NTEventLogHandler(self.__platform["application_name"], logtype="Application")
        ## default log directory
        self.__platform["logging_directory"] = self.configuration_directory
        ## how to start commands with files
        self.command_file = "%s \"%s\""
        ## hidden files
        self.__platform["hidden"] = self.__windows_hidden

    def __windows_hidden(self, path):
        """Check path for hidden files or directories on windows."""
        path = os.path.abspath(path)
        if os.path.exists(path):
            result = False
            for item in path.split(os.path.sep):
                if len(item) > 0 and win32api.FILE_ATTRIBUTE_HIDDEN in win32file.GetFileAttributes(item):
                    ## at least one component of path is hidden
                    result = True
            return result
        else:
            raise latua.error.PlatformError("hidden",
                                            "%s does not exists" % (path))

if __name__ == "__main__":
    print """
do not run this file directly, use latua classes

    """



# -*- coding:utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - test/latua/core/test_system.py

latua test class for system

"""

__version__ = "$Revision: 190 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/test/latua/_system/test_system.py $

## standard modules
import unittest

## latua modules
import latua

class SystemTestCase(unittest.TestCase):
    """Test for latua system functions."""
    def setUp(self):
        """Test set up."""
        self.__system = latua.System()

    def test_sort(self):
        """Test system sorting of a dictionary."""
        dictionary = {"c": 1, "b": 2, "a": 3}
        result = self.__system.sort(dictionary)
        self.assertEqual(result, [3, 2, 1],
                         "sorting of dictionary by key failed")
        result = self.__system.sort(dictionary, values=True)
        self.assertEqual(result, [1, 2, 3],
                         "sorting of dictionary by value failed")

    def test_system(self):
        """Test system items."""
        result = self.__system.system("test")
        self.assertEqual(result, False, "failed to test non-system item")
        result = self.__system.system("_test")
        self.assertEqual(result, True, "failed to test system item")

    def tearDown(self):
        """Clean up after tests."""
        self.__system = None

if __name__ == "__main__":
    print """
do not run this file directly, use latua test script

    """



# -*- coding:utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - test/latua/_base/test_i18n.py

latua test class for i18n

"""

__version__ = "$Revision: 139 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/test/latua/_base/test_i18n.py $

## standard modules
import unittest

## latua modules
import latua
import latua._context
import latua.error

class I18nTestCase(unittest.TestCase):
    """Test cases for latuas i18n classes."""
    def setUp(self):
        """Set up needed objects."""
        latua._context._languages = []
        self.__base = latua.Base()

    def test_context(self):
        """Test i18n context initialization."""
        ## latua has no translations
        self.assert_(len(latua._context._languages) == 0,
                     "found items in i18n languages")

    def test_initialization(self):
        """Test i18n languages initialization."""
        ## latua has no translations
        self.assertRaises(latua.error.I18nError, self.__base.i18n.install_translation)

    def test_missing(self):
        """Test i18n missing language."""
        latua._context._languages.append("latua_test_language")
        self.assertRaises(latua.error.I18nError, self.__base.i18n.install_translation,
                          "latua_test")

    def test_reinitialization(self):
        """Test i18n reinitialization from context."""
        ## latua has no translations
        latua._context._languages.append("latua_test_language")
        self.__base = None
        ## context should stay after removal of object
        self.assert_(len(latua._context._languages) == 1,
                     "i18n context removed after object removal")
        ## reinitialize class
        self.__base = latua.Base()
        ## check for changed context
        self.assertEqual(self.__base.i18n.languages, ["latua_test_language"],
                         "i18n was and not updated from context")

    def tearDown(self):
        """Clean up after tests."""
        self.__base = None
        latua._context._languages = []

if __name__ == "__main__":
    print """
do not run this file directly, use latua test script

    """



# -*- coding:utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - test/latua/core/test_configuration.py

latua test class for configuration

"""

__version__ = "$Revision: 199 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/test/latua/_system/test_configuration.py $

## standard modules
import os
import tempfile
import unittest

## latua modules
import latua
import latua.error

class ConfigurationTestCase(unittest.TestCase):
    """Test for saving and loading configuration."""
    def setUp(self):
        """Test set up."""
        self.__system = latua.System()
        self.__test_directory = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, os.pardir))
        self.__test_file_handle, self.__test_file_name = tempfile.mkstemp(prefix="latua_test_temp_", dir=self.__test_directory)
        self.__configuration = """\
[test_section]
test_option = test_value

"""

    def test_directory(self):
        """Test configuration directory exceptions."""
        self.assertRaises(latua.error.ConfigurationError,
                          self.__system.configuration.write_file, "")

    def test_exists(self):
        """Test configuration file exists execption."""
        self.assertRaises(latua.error.ConfigurationError,
                          self.__system.configuration.read_file, "")

    def test_open(self):
        """Test configuration open exceptions."""
        os.chmod(self.__test_file_name, 0000)
        self.assertRaises(latua.error.ConfigurationError,
                          self.__system.configuration.write_file,
                          self.__test_file_name)
        ## no need to chmod back to 0600 os.remove() works on 0000 too

    def test_parse(self):
        """Test configuration parse error."""
        os.write(self.__test_file_handle,
                 self.__configuration.replace("=", ""))
        self.assertRaises(latua.error.ConfigurationError,
                          self.__system.configuration.read_file,
                          self.__test_file_name)

    def test_read(self):
        """Test configuration file reading."""
        os.write(self.__test_file_handle, self.__configuration)
        self.__system.configuration.read_file(self.__test_file_name)
        result = self.__system.configuration.has_section("test_section")
        self.assertEqual(result, True,
                         "configuration does not contain section")
        result = self.__system.configuration.has_option("test_section",
                                                        "test_option")
        self.assertEqual(result, True,
                         "configurations does not contain option")
        result = self.__system.configuration.get("test_section",
                                                 "test_option")
        self.assertEqual(result, "test_value",
                         "configuration option has wrong value")

    def test_write(self):
        """Test configuration file writing."""
        self.__system.configuration.add_section("test_section")
        result = self.__system.configuration.set("test_section",
                                                 "test_option",
                                                 "test_value")
        self.__system.configuration.write_file(self.__test_file_name)
        result = ""
        while True:
            data = os.read(self.__test_file_handle, 512)
            if len(data) == 0:
                break
            result = "%s%s" % (result, data)
        self.assertEqual(result, self.__configuration,
                         "failed to write configuration")

    def tearDown(self):
        """Clean up after tests."""
        self.__configuration = None
        os.close(self.__test_file_handle)
        os.remove(self.__test_file_name)
        self.__test_file_handle = None
        self.__test_file_name = None
        self.__test_directory = None
        self.__system = None

if __name__ == "__main__":
    print """
do not run this file directly, use latua test script

    """



# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - latua/_system/_crypt.py

latua crypt classes

"""

__version__ = "$Revision: 137 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/latua/_system/_crypt.py $

## standard modules
import os
import md5
import sha
import string

class _Crypt(object):
    """Crypt texts with md5 or sha1."""
    def __init__(self):
        ## signs between salt and hash
        self.__cutter = "#*$*#"
        ## supported crypt algorithm
        self._supported = ["md5", "sha1"]

    def generate(self, length=8, characters=None):
        """Generates a random text with given length from given chars."""
        if characters == None:
            characters = "%s%s" % (string.letters, string.digits)
        text = []
        ## urandom is unpredictable enough and
        ## more secure then random.random()
        data = os.urandom(length)
        for item in range(len(data)):
            ## append every letter
            text.append(characters[ord(data[item]) % len(characters)])
        return "".join(text)

    def encrypt(self, text, algorithm="md5"):
        """Encrypt a given text."""
        crypted_text = None
        if algorithm not in self._supported:
            ## actual algorithm is not suppoerted
            raise ValueError, "unsupported crypt alogrithm: %s" % (algorithm)
        if algorithm == "sha1":
            ## use sha-1
            salt = sha.new(str(os.urandom(32))).hexdigest()[:5]
            hash_value = sha.new("%s%s" % (salt, text)).hexdigest()
            crypted_text = "%s%s%s%s%s" % (algorithm, self.__cutter, salt, self.__cutter, hash_value)
        else:
            ## use md5
            salt = md5.new(str(os.urandom(32))).hexdigest()[:5]
            hash_value = md5.new("%s%s" % (salt, text)).hexdigest()
            crypted_text = "%s%s%s%s%s" % (algorithm, self.__cutter, salt, self.__cutter, hash_value)
        return crypted_text

    def check(self, text, crypted_text):
        """Check a text against encrypted."""
        result = False
        algorithm, salt, hash_value = crypted_text.split(self.__cutter)
        if algorithm == "sha1":
            ## use sha-1
            if hash_value == sha.new("%s%s" % (salt, text)).hexdigest():
                result = True
        else:
            ## use md5
            if hash_value == md5.new("%s%s" % (salt, text)).hexdigest():
                result = True
        return result

if __name__ == "__main__":
    print """
do not run this file directly, use latua classes

    """



# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - latua/_system/_files.py

files class for working on files and directories

"""

__version__ = "$Revision: 176 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/latua/_system/_files.py $

## standard modules
import os
import stat

class _Files(object):
    """Files class for working on files and directories."""
    def __init__(self):
        pass

    def __rwx(self, read_bit, write_bit, execute_bit):
        """Format three permission bits."""
        read = "-"
        write = "-"
        execute = "-"
        if not read_bit == 0:
            read = "r"
        if not write_bit == 0:
            write = "w"
        if not execute_bit == 0:
            execute = "x"
        return "%s%s%s" % (read, write, execute)

    def permission(self, path):
        """Check permissions."""
        stats = os.stat(path)
        mode = stats[stat.ST_MODE]
        ## format permissions
        owner = self.__rwx(mode & stat.S_IRUSR,
                           mode & stat.S_IWUSR,
                           mode & stat.S_IXUSR)
        group = self.__rwx(mode & stat.S_IRGRP,
                           mode & stat.S_IWGRP,
                           mode & stat.S_IXGRP)
        other = self.__rwx(mode & stat.S_IROTH,
                           mode & stat.S_IWOTH,
                           mode & stat.S_IXOTH)
        return (owner, group, other)

    def integrity(self, path, files):
        """Check for integrity of files in a directory."""
        missing_files = []
        for item in files:
            ## check for existence of all files
            if not os.path.isfile(os.path.join(path, item)):
                missing_files.append(item)
        return missing_files

    def search(self, path, type="", extension="", absolute=True):
        """Lists all files or directories with given extension from path."""
        result = []
        if absolute==True:
            ## use absolute path
            path = os.path.abspath(path)
        ## find all files
        for root, directories, files in os.walk(path):
            if type == "file" or type == "":
                for item in files:
                    ## check extension of all files
                    file_extension = os.path.splitext(os.path.join(root, item))[1].lower()
                    if extension == file_extension or extension == "":
                        ## extension matches or no extension given
                        result.append(os.path.join(root, item))
            elif type == "directory" or type == "":
                for item in directories:
                    ## append file
                    result.append(os.path.join(root, item))
            else:
                ## add support for more file types like:
                ##
                ## block device
                ## character device
                ## (symbolic) link
                ## fifo
                ## socket
                ##
                ## actual file type is not supported
                raise ValueError, "unsupported file type: %s" % (type)
        return result

if __name__ == "__main__":
    print """
do not run this file directly, use latua classes

    """



# -*- coding:utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - test/latua/_base/test_platform.py

latua test class for platform

"""

__version__ = "$Revision: 198 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/test/latua/_base/test_platform.py $

## standard modules
import os
import unittest

## latua modules
import latua
import latua._context

class PlatformTestCase(unittest.TestCase):
    """Test cases for latuas platform classes."""
    def setUp(self):
        """Set up needed objects."""
        latua._context._platform = {}
        self.__base = latua.Base()

    def test_application(self):
        """Test platform application values."""
        self.assert_(len(self.__base.platform.application_name) > 0,
                     "platform user empty")
        ## application directory should exist (containing test script)
        self.assertEqual(os.path.isdir(self.__base.platform.application_directory),
                         True,
                         "application directory %s does not exists" % (self.__base.platform.application_directory))

    def test_context(self):
        """Test platform context initialization."""
        ## check actual number of platform dependent variables
        self.assertEqual(len(latua._context._platform), 14,
                         "wrong length of platform context")

    def test_dictionary(self):
        """Test platform class dictionary update."""
        platform = getattr(self.__base.platform, "_Platform__platform")
        self.assert_(len(platform) >= 0,
                     "no items found in platform dictionary")
        for item in platform:
            self.assertEqual(platform[item], getattr(self.__base.platform, item),
                             "%s is not updated in class dictionary" % (item))

    def test_directories(self):
        """Test platform directory values."""
        self.assertEqual(os.path.isdir(self.__base.platform.modules_directory),
                         True,
                         "modules directory %s does not exists" % (self.__base.platform.modules_directory))
        self.assertEqual(os.path.isdir(self.__base.platform.home_directory),
                         True,
                         "home directory %s does not exists" % (self.__base.platform.home_directory))
        self.assert_(len(self.__base.platform.data_directory) > 0,
                     "data directory is empty")
        self.assert_(len(self.__base.platform.configuration_directory) > 0,
                     "configuration directory is empty")

    def test_language(self):
        """Test platform language values."""
        self.assert_(len(self.__base.platform.languages) > 0,
                     "languages list is empty")
        ## locales directory should exist on unix
        ## but on other platforms often locales directory does not exists
        ## like on os x where sys-prefix points to python directory, so if no
        ## other python application is installed via distutils locales
        ## directory is not already created
        self.assert_(len(self.__base.platform.locales_directory) > 0,
                     "locales directory is empty")

    def test_logging(self):
        """Test platform logging values."""
        ## logging handler should not be none
        self.assertNotEqual(self.__base.platform.logging_handler, None,
                            "no logging handler set")
        self.assert_(len(self.__base.platform.logging_directory) > 0,
                     "logging directory is empty")

    def test_reinitialization(self):
        """Test platform reinitialization from context."""
        self.__base = None
        ## context should stay after removal of object
        self.assert_(len(latua._context._platform) >= 0,
                     "platform context removed after object removal")
        ## change context
        latua._context._platform["user"] = "latua_test_user"
        ## reinitialize class
        self.__base = latua.Base()
        ## check for changed context
        self.assertEqual(self.__base.platform.user, "latua_test_user",
                         "platform was and not updated from context")

    def test_user(self):
        """Test platform user value."""
        self.assert_(len(self.__base.platform.user) > 0, "platform user empty")

    def tearDown(self):
        """Clean up after tests."""
        self.__base = None
        latua._context._platform = {}

if __name__ == "__main__":
    print """
do not run this file directly, use latua test script

    """



# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - latua/_system/_modules.py

modules class for working with modules

"""

__version__ = "$Revision: 191 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/latua/_system/_modules.py $

## standard modules
import os
import sys
import imp

## latua modules
import latua.error

class _Modules(object):
    """Modules class for working with modules."""
    def __init__(self):
        pass

    def _import(self, module_path, class_name=None):
        """Import module from path and get given variable."""
        return_value = None
        path = module_path.split(".")
        name = path.pop()
        try:
            ## see if the module has already been imported
            module = sys.modules[name]
        except KeyError, error:
            module = __import__(module_path, globals(), locals(), [""])
        return_value = module
        if class_name and not return_value == None:
            ## get only a specific class from module
            return_value = getattr(module, class_name)()
        return return_value

    def append(self, target, path, value=None):
        """Create or append a module to another."""
        module_path = [target.__name__]
        name = ""
        if not path == "":
            ## split module name from element of path
            name = path.split(".").pop()
        else:
            raise latua.error.ModulesError(target.__name__, "given module path is empty")
        ## iterate over path
        for item in path.split("."):
            if not hasattr(".".join(module_path), item):
                ## module does not already exists
                new_module = imp.new_module(item)
                if item == name and not value == None:
                    ## set last element to given module
                    new_module = value
                setattr(self._import(".".join(module_path)), item, new_module)
                ## append module to sys search path
                sys.modules["%s.%s" % (".".join(module_path), item)] = new_module
                module_path.append(item)

    def filename_modulename(self, filename):
        """Convert filename to modulename."""
        modulename = filename.replace(os.sep, ".")
        ## strip .py
        modulename = os.path.splitext(modulename)[0]
        return modulename

    def modulename_filename(self, modulename):
        """Convert modulename to filename."""
        filename = modulename.replace(".", os.sep)
        ## append .py
        filename = "%s%spy" % (filename, os.path.extsep)
        return filename

##    def modulename(self):
##        """Find name of the calling module."""
##        if self.__class__.__module__ == "latua._base":
##            ## class is only used no inheritance
##            return sys.argv[0]
##        else:
##            ## inherited from class in child class
##            if self.__class__.__module__ == "__main__":
##                return sys.argv[0]
##            return self.__class__.__module__

if __name__ == "__main__":
    print """
do not run this file directly, use latua classes

    """



# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - latua/_base/_i18n.py

classes for internationalization

"""

__version__ = "$Revision: 203 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/latua/_base/_i18n.py $

## standard modules
import locale
import gettext

## latua modules
import latua._context

class _I18n(object):
    """Load and install languages."""
    def __init__(self):
        ## get platform data
        self.__platform = latua._base._platform._Platform()
        ## available languages with installed translations
        self.languages = latua._context._languages
        ## maybe no translations found
        ## retry again on every init
        ## bad for performance but gives the
        ## possibility to add languages on the fly
        if len(self.languages) == 0:
            ## find all available languages with installed translations
            self.languages = gettext.find(self.__platform.application_name,
                                          self.__platform.locales_directory,
                                          languages=self.__platform.languages,
                                          all=True)
            ## set the locale for all categories
            ## to the users default setting
            locale.setlocale(locale.LC_ALL, '')

    def install_translation(self, language=None):
        """Install actual translation."""
        if len(self.languages) == 0:
            raise latua.error.I18nError(None, "no languages available",
                                        self.languages)
        if language not in self.languages:
            raise latua.error.I18nError(language, "language is not available",
                                        self.languages)
        ## get translation
        translation = gettext.translation(self.__platform.application_name,
                                          self.__platform.locales_directory,
                                          languages=[language],
                                          unicode=1,
                                          fallback=True)
        ## change translation on the fly
        translation.install()

if __name__ == "__main__":
    print """
do not run this file directly, use latua classes

    """



# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - latua/_system/_system.py

system class contains generic system services

"""

__version__ = "$Revision: 190 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/latua/_system/_system.py $

## standard modules
import os
import time

## latua modules
import latua._system._crypt
import latua._system._files
import latua._system._modules
import latua._system._configuration

class _System(object):
    """System services."""
    def __init__(self):
        ## add configuration object
        self.configuration = latua._system._configuration._Configuration()
        ## add crypt object
        self.crypt = latua._system._crypt._Crypt()
        ## add files object
        self.files = latua._system._files._Files()
        ## add modules object
        self.modules = latua._system._modules._Modules()

    def sort(self, dictionary, values=False):
        """Sort a dict by keys or values."""
        if values == True:
            ## sort by values
            dictionary_values = dictionary.values()
            dictionary_values.sort()
            return dictionary_values
        else:
            ## sort by keys
            dictionary_keys = dictionary.keys()
            dictionary_keys.sort()
            return [dictionary[key] for key in dictionary_keys]

    def system(self, item):
        """Check if item belongs to system."""
        result = False
        if item.startswith("_"):
            ## system item starts with underscore
            result = True
        return result

if __name__ == "__main__":
    print """
do not run this file directly, use latua classes

    """



#!/usr/bin/env python
# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
## added to test svn mail test4

"""

latua - setup.py

latua installation

"""

__version__ = "$Revision: 167 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/setup.py $

## standard modules
import os
import sys
import glob
from distutils.core import setup

## latua modules
import latua

class _Install(latua.Base):
    """Installer class."""
    def __init__(self):
        latua.Base.__init__(self)
        ## initialization of system
        self.__system = latua.System()
        ## initialization of version information
        self.__version = latua.Version()

    def __keywords(self):
        """Define additional distutils keywords."""
        setup_keywords = {}
        if sys.version >= (2,5):
            ## new distutils keywords since python 2.5
            setup_keywords["requires"] = []
            if sys.platform == "win32":
                ## latua on windows requires win32 extensions
                setup_keywords["requires"] = ["pywin32"]
            setup_keywords["provides"] = ["%s (=0.1)" % (self.platform.application_name)]
            setup_keywords["obsolete"] = []
        return setup_keywords

    def run(self):
        """Run installation."""
        setup_keywords = self.__keywords()
        ## installation
        setup(name = "latua",
              version = self.__version.latua_version,
              license = self.__version.license,
              author = self.__version.author,
              author_email = self.__version.email,
              url = self.__version.url,
              download_url = self.__version.download_url,
              description = self.__version.description,
              long_description = self.__version.long_description,
              classifiers = self.__version.classifiers,
              packages = ["latua", "latua._base", "latua._system"],
              scripts = ["latua_translations", "latua_propset"],
              **setup_keywords)

## last line but first step
if __name__ == "__main__":
    installer = _Install()
    installer.run()



# -*- coding:utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke, Jonas Weismueller (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.

"""

latua - test/latua/test_singleton.py

latua test class for singleton

"""

__version__ = "$Revision: 139 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/test/latua/test_singleton.py $

## standard modules
import unittest

## latua modules
import latua.singleton

class SingletonTestCase(unittest.TestCase):
    """Test cases for latuas singleton and borg pattern."""
    def setUp(self):
        """Set up needed objects."""
        self.__borg_a = latua.singleton.Borg()
        self.__borg_b = latua.singleton.Borg()
        self.__singleton_a = latua.singleton.Singleton()
        self.__singleton_b = latua.singleton.Singleton()

    def test_object(self):
        """Test singleton and borg object ids."""
        self.assertNotEqual(id(self.__borg_a), id(self.__borg_b), "borgs does not have different object ids")
        self.assertEqual(id(self.__singleton_a), id(self.__singleton_b), "singletons does not have the same id")

    def test_shared(self):
        """Test singleton borg shared state."""
        self.__borg_a.attribute = "test"
        self.assertEqual(self.__borg_b.attribute, "test", "borg does not get shared state")
        ## and the other way around
        self.__borg_b.attribute = "test_attribute"
        self.assertEqual(self.__borg_a.attribute, "test_attribute", "borg does not share state")
        self.assertEqual(self.__borg_a.attribute, self.__borg_b.attribute, "borg does not share state")

    def test_singleton(self):
        """Test singleton state."""
        self.__singleton_a.attribute = "test"
        self.assertEqual(self.__singleton_b.attribute, "test", "singleton does not get shared state")
        ## and the other way around
        self.__singleton_b.attribute = "test_attribute"
        self.assertEqual(self.__singleton_a.attribute, "test_attribute", "singleton does not share state")
        self.assertEqual(self.__singleton_a.attribute, self.__singleton_b.attribute, "singleton does not share state")

    def tearDown(self):
        """Clean up after tests."""
        self.__borg_a = None
        self.__borg_b = None

if __name__ == "__main__":
    print """
do not run this file directly, use latua test script

    """
